icqr: icqr

Description Usage Arguments Value

View source: R/icqr.R

Description

This function returns the coefficient vector beta in the model T = exp(z beta(u)) instrumental censored quantile regression.

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
icqr(
  data,
  u,
  attempts = 10,
  method = "Brent",
  lower = -5,
  upper = 5,
  deltaName = c("delta"),
  timeName = c("y"),
  covNames = c("x"),
  IVNames = c("w"),
  Nbootstrap = NA,
  bootstrapEpsilon = 1,
  verbose = FALSE
)

Arguments

data

dataset as dataframe

attempts

attempts to estimate beta, to avoid local minima

method

estimation method, see optim function in stats package.

lower

1 dimension: (lower,upper) = interval where beta is searched (see optim function in stats package.),more dimensions: interval for uniform random starting point for beta, in each component

upper

see "lower" parameter

deltaName

variable name of the censor variable: 0 censored, 1 not censored. It is passed as list of string

timeName

variable name of the time variable. It is passed as list of string

covNames

variable names of the covriate. It is passed as list of string

IVNames

variable names for the Instrumental variable, it has to include exogenuos variable name. It is passed as list of string

Nbootstrap

number of bootstrap resampling. NA in case of not boostrap

bootstrapEpsilon

when bootstrap, reaserch the minimum in (beta-epsilon, beta + epsilon), vector interval

verbose

print during estimation

Value

estimated beta vector parameter


tedescolor/icqr documentation built on Dec. 23, 2021, 8:43 a.m.