upperQuantileIdentification: upperQuantileIdentification

Description Usage Arguments Value

View source: R/upperQuantileIdentification.R

Description

This function returns the a suggested upper bound for the quantile that can be identified depennding on the data.

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
upperQuantileIdentification(
  data,
  attempts = 1,
  method = "Brent",
  lower = -5,
  upper = 5,
  deltaName = c("delta"),
  timeName = c("y"),
  covNames = c("x"),
  IVNames = c("w"),
  us = seq(0.1, 0.9, by = 0.1)
)

Arguments

data

dataset as dataframe

attempts

attempts to estimate beta, to avoid local minima

method

estimation method, see optim function in stats package.

lower

1 dimension: (lower,upper) = interval where beta is searched (see optim function in stats package.),more dimensions: interval for uniform random starting point for beta, in each component

upper

see "lower" parameter

deltaName

variable name of the censor variable: 0 censored, 1 not censored. It is passed as list of string

timeName

variable name of the time variable. It is passed as list of string

covNames

variable names of the covriate. It is passed as list of string

IVNames

variable names for the Instrumental variable, it has to include exogenuos variable name. It is passed as list of string

us

grid of quantiles that among which the suggested quantile is picked

Value

estimated beta vector parameter


tedescolor/icqr documentation built on Dec. 23, 2021, 8:43 a.m.