Description Usage Arguments Value
View source: R/upperQuantileIdentification.R
This function returns the a suggested upper bound for the quantile that can be identified depennding on the data.
1 2 3 4 5 6 7 8 9 10 11 12 |
data |
dataset as dataframe |
attempts |
attempts to estimate beta, to avoid local minima |
method |
estimation method, see optim function in stats package. |
lower |
1 dimension: (lower,upper) = interval where beta is searched (see optim function in stats package.),more dimensions: interval for uniform random starting point for beta, in each component |
upper |
see "lower" parameter |
deltaName |
variable name of the censor variable: 0 censored, 1 not censored. It is passed as list of string |
timeName |
variable name of the time variable. It is passed as list of string |
covNames |
variable names of the covriate. It is passed as list of string |
IVNames |
variable names for the Instrumental variable, it has to include exogenuos variable name. It is passed as list of string |
us |
grid of quantiles that among which the suggested quantile is picked |
estimated beta vector parameter
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.